//
//  MasterViewController.swift
//  SVCDemo
//
//  Created by Merlyn on 10/3/14.
//  Copyright (c) 2014 The App Lady. All rights reserved.
//

import UIKit

class MasterViewController: UITableViewController, UISplitViewControllerDelegate {
    
    // Declare an empty Ojective-C immutable dictionary
    var flowerCollection = NSDictionary()
       
    override func awakeFromNib() {
        super.awakeFromNib()
        if UIDevice.currentDevice().userInterfaceIdiom == .Pad {
            self.clearsSelectionOnViewWillAppear = false
            self.preferredContentSize = CGSize(width: 320.0, height: 600.0)
        }
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        flowerCollection = loadFlowersFromPList()
        
        /************** DEBUG CODE ************
        let dictKeys: Array = flowerCollection.allKeys, dictValues: Array = flowerCollection.allValues
        
        for var i = 1; i < flowerCollection.count; ++i {
            println("\(dictKeys[i]) | \(dictValues[i])\n")
        }
        **************************************/
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    // MARK: - Segues
    
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        if segue.identifier == "showDetail" {
            if let indexPath = self.tableView.indexPathForSelectedRow() {
                //1. Put the secondary view controller in a variable called vc
                let vc = (segue.destinationViewController as UINavigationController).topViewController as DetailViewController
                
                //2. Assign the displayModeButtonItem to the vc navigation bar
                vc.navigationItem.leftBarButtonItem = self.splitViewController?.displayModeButtonItem()
                vc.navigationItem.leftItemsSupplementBackButton = true
                
                //3. Pass the selected table view cell's data to the vc's selectedFlower array variable
                let flowerNames = flowerCollection.allKeys
                let flowerUrls = flowerCollection.allValues
                let name = flowerNames[indexPath.row ] as String
                let link = flowerUrls[indexPath.row] as String
                let flowerObject: Array = [name, link]
                vc.selectedFlower = flowerObject
            }
        }
    }
    
    // MARK: - Table view data source

    override func numberOfSectionsInTableView(tableView: UITableView) -> Int {
        return 1
    }

    override func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        //return tableDataSource.count
        return flowerCollection.count
    }
  
    override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCellWithIdentifier("Cell", forIndexPath: indexPath) as UITableViewCell
        
        // Convert an element of the flowerUrls array to a Swift String befor assinging it to the urlString variable
        let flowerUrls: Array = flowerCollection.allValues
        let urlString = flowerUrls[indexPath.row] as String
        
        // Get the image from the urlString and assign it to the tableView cell's imageView property
        cell.imageView?.image = MasterViewController.getPhotoFromUrl(urlString)

        // Get an element of the flowerNames array, convert it to a Swift String, then assign it to the tableView cell's textLabel property
        let flowerNames: Array = flowerCollection.allKeys
        cell.textLabel?.text = flowerNames[indexPath.row] as? String
        return cell
    }

    // MARK: - Data Model
    
    // This function fetch a photo from the url passed to it as a parameter and returen it as an image object
    class func getPhotoFromUrl(let photoUrl:String) -> UIImage {
        var err: NSError?
        var rawData: NSData
        
        var url = NSURL.URLWithString(photoUrl)
        if url == nil {
            url = NSURL.URLWithString("http://theapplady.net/wp-content/uploads/2014/05/noimage.png")
            rawData = NSData.dataWithContentsOfURL(url, options: NSDataReadingOptions.DataReadingMappedIfSafe, error: &err)
        } else {
            rawData = NSData.dataWithContentsOfURL(url, options: NSDataReadingOptions.DataReadingMappedIfSafe, error: &err)
        }
        
        // Return the image pass to the function as an argument or the image called noimage.png
        return UIImage(data:rawData)
    }
    
    // This function fetch dictionary entries from the plist file that's in the project's bundle and rturn them to its caller
    private func loadFlowersFromPList() -> NSDictionary {
        let path = NSBundle.mainBundle().pathForResource("Flowers", ofType: "plist")
        let flowerCollection = NSDictionary(contentsOfFile: path!)
        
        /************* DEBUG CODE ***************
        println(flowerCollection.description)
        println(path)
        ****************************************/
        return flowerCollection
    }

}
